@@ -20,6 +20,7 @@ from cognite.experimental._api.pnid_object_detection import PNIDObjectDetectionA
 from cognite.experimental._api.pnid_parsing import DiagramsAPI, PNIDParsingAPI
 from cognite.experimental._api.templatecompletion import ExperimentalTemplatesAPI
 from cognite.experimental._api.types import TypesAPI
+from cognite.experimental._api.vision import VisionAPI
 
 APIClient.RETRYABLE_POST_ENDPOINTS |= {
     f"/{api}/{endpoint}"
@@ -116,3 +117,4 @@ class CogniteClient(Client):
         self.diagrams = DiagramsAPI(self._config, api_version=self._API_VERSION, cognite_client=self)
         # template completion only
         self.templates = ExperimentalTemplatesAPI(self._config, api_version=self._API_VERSION, cognite_client=self)
+        self.vision = VisionAPI(self._config, api_version="playground", cognite_client=self)
